**Example 1: 删除资源版本**



Input: 

```
tccli oceanus DeleteResourceConfigs --cli-unfold-argument  \
    --ResourceId xx \
    --ResourceConfigVersions 1
```

Output: 
```
{
    "Response": {
        "RequestId": "5d5a201f-0a3d-485f-a82f-3c73ccca348a"
    }
}
```

